library verify_email;

import 'dart:math';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:mailer/mailer.dart';
import 'package:mailer/smtp_server/gmail.dart';

class VerifyEmail {
  ///This method will send an email to your user with a code that is then asked to write in a textfield
  ///[email]The email address that you want to send verification to
  ///[appName] This is used for email header, if provided, it makes the email clearer and more personal
  ///[credential] The accessCredential got from Google Authentication (google_sign_in package), go to pub.dev/packages/google_sign_in to implement.
  ///[senderEmail] The email address that sends the email, has to be the same as Google Sign-in account
  Future<bool> verify(
      {@required BuildContext context,
      @required String email,
      String appName,
      @required String credential,
      @required String senderEmail}) async {
    bool isVerified = false;
    int code = Random().nextInt(999999) + 1;
    String typedInCode;
    //Checking for null
    if (email != null && credential != null) {
      try {
        final smtpServer = gmailSaslXoauth2(senderEmail, credential);

        final message = Message()
          ..from = Address(senderEmail, 'Your name')
          ..recipients.add(email)
          ..subject =
              'Verify your email${appName != null ? 'for $appName' : ''}'
          ..html =
              "<h1>Hello!</h1>\n<p>Please verify your email with the following code:</p>\n<p><strong>$code</strong></p>\n<p>Thank you!</p>";

        try {
          final sendReport = await send(message, smtpServer);
          print('Message sent: ' + sendReport.toString());
          await showDialog(
              context: context,
              builder: (_) => AlertDialog(
                    title: Text("Verify"),
                    content: Column(
                      children: [
                        Text(
                            "Verify your email by typing in the code that was sent to\n$email"),
                        Expanded(child: TextField(
                          onChanged: (value) {
                            typedInCode = value;
                          },
                        )),
                      ],
                    ),
                    actions: [
                      MaterialButton(
                        child: Text("VERIFY"),
                        onPressed: () {
                          try {
                            if (int.parse(typedInCode) == code) {
                              isVerified = true;
                            }
                          } catch (e) {
                            //Probably the code typed in wasn't only numbers
                          }
                        },
                      )
                    ],
                  ));
        } on MailerException catch (e) {
          print('Message not sent.');
          for (var p in e.problems) {
            print('Problem: ${p.code}: ${p.msg}');
          }
        }
      } catch (e) {
        //Probably your credential was wrong
        isVerified = false;
      }
    } else {
      //Email is null so program won't try emailing to this address
      isVerified = false;
    }
    return isVerified;
  }
}
